nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Mrt0

Struct Mrt0 

pub struct Mrt0 { /* private fields */ }
Multi-Rate Timer (MRT)

Implementations

Source

impl Mrt0

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn channel(self, n: usize) -> Channel

no description available

pub const fn modcfg(self) -> Reg<Modcfg, RW>

Module Configuration register. This register provides information about this particular MRT instance, and allows choosing an overall mode for the idle channel feature.

pub const fn idle_ch(self) -> Reg<IdleCh, R>

Idle channel register. This register returns the number of the first idle channel.

pub const fn irq_flag(self) -> Reg<IrqFlag, RW>

Global interrupt flag register